summaryrefslogtreecommitdiffstats
path: root/ksquirrel/ksquirrelpart/sq_codecsettingsskeleton.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksquirrel/ksquirrelpart/sq_codecsettingsskeleton.ui.h')
-rw-r--r--ksquirrel/ksquirrelpart/sq_codecsettingsskeleton.ui.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/ksquirrel/ksquirrelpart/sq_codecsettingsskeleton.ui.h b/ksquirrel/ksquirrelpart/sq_codecsettingsskeleton.ui.h
index 1ea9d6b..5c6433b 100644
--- a/ksquirrel/ksquirrelpart/sq_codecsettingsskeleton.ui.h
+++ b/ksquirrel/ksquirrelpart/sq_codecsettingsskeleton.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/
@@ -13,29 +13,29 @@ void SQ_CodecSettingsSkeleton::init()
sett = 0;
}
-void SQ_CodecSettingsSkeleton::addSettingsWidget(const QString &path)
+void SQ_CodecSettingsSkeleton::addSettingsWidget(const TQString &path)
{
- w = QWidgetFactory::create(path, 0, this, "skeleton_settings");
- QWidget *fake;
+ w = TQWidgetFactory::create(path, 0, this, "skeleton_settings");
+ TQWidget *fake;
if(w)
- fake = w;
+ fake = TQT_TQWIDGET(w);
else
{
pushApply->setEnabled(false);
pushOK->setEnabled(false);
- QTextEdit *t = new QTextEdit(i18n("Error loading widget from <b>%1</b>. Please check your installation or contact <a href=\"mailto:ksquirrel.iv@gmail.com\">ksquirrel.iv@gmail.com</a>").arg(path), QString::null, groupBox);
+ TQTextEdit *t = new TQTextEdit(i18n("Error loading widget from <b>%1</b>. Please check your installation or contact <a href=\"mailto:ksquirrel.iv@gmail.com\">ksquirrel.iv@gmail.com</a>").tqarg(path), TQString(), groupBox);
t->setReadOnly(true);
fake = t;
}
- fake->reparent(groupBox, QPoint(0,0), true);
+ fake->reparent(groupBox, TQPoint(0,0), true);
- QGridLayout *grid = new QGridLayout(groupBox, 1, 1, 11, 6);
+ TQGridLayout *grid = new TQGridLayout(groupBox, 1, 1, 11, 6);
grid->addMultiCellWidget(fake, 1, 1, 0, 3);
- QSpacerItem *spacer = new QSpacerItem(15, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);
+ TQSpacerItem *spacer = new TQSpacerItem(15, 1, TQSizePolicy::Minimum, TQSizePolicy::Expanding);
grid->addItem(spacer, 2, 1);
}
@@ -44,16 +44,16 @@ void SQ_CodecSettingsSkeleton::recursivelyReadWrite(fmt_settings &settings, bool
if(!w)
return;
- QObjectList *ch = const_cast<QObjectList *>(w->children());
+ TQObjectList ch = w->childrenListObject();
fmt_settings::iterator t;
- for(QObjectList::iterator it = ch->begin();it != ch->end();++it)
+ for(TQObjectList::iterator it = ch.begin();it != ch.end();++it)
{
t = settings.find((*it)->name());
- if((*it)->inherits("QCheckBox"))
+ if((*it)->inherits(TQCHECKBOX_OBJECT_NAME_STRING))
{
- QCheckBox *c = dynamic_cast<QCheckBox *>(*it);
+ TQCheckBox *c = dynamic_cast<TQCheckBox *>(*it);
if(c && t != settings.end())
{
@@ -63,9 +63,9 @@ void SQ_CodecSettingsSkeleton::recursivelyReadWrite(fmt_settings &settings, bool
(*t).second.bVal = c->isChecked();
}
}
- else if((*it)->inherits("QButtonGroup"))
+ else if((*it)->inherits(TQBUTTONGROUP_OBJECT_NAME_STRING))
{
- QButtonGroup *c = dynamic_cast<QButtonGroup *>(*it);
+ TQButtonGroup *c = dynamic_cast<TQButtonGroup *>(*it);
if(c && t != settings.end())
{
@@ -75,9 +75,9 @@ void SQ_CodecSettingsSkeleton::recursivelyReadWrite(fmt_settings &settings, bool
(*t).second.iVal = c->selectedId();
}
}
- else if((*it)->inherits("QSlider"))
+ else if((*it)->inherits(TQSLIDER_OBJECT_NAME_STRING))
{
- QSlider *c = dynamic_cast<QSlider *>(*it);
+ TQSlider *c = dynamic_cast<TQSlider *>(*it);
if(c && t != settings.end())
{
@@ -114,10 +114,10 @@ void SQ_CodecSettingsSkeleton::recursivelyReadWrite(fmt_settings &settings, bool
(*t).second.dVal = d->value();
}
}
- // QSpinBox should be checked after KDoubleSpinBox !
- else if((*it)->inherits("QSpinBox"))
+ // TQSpinBox should be checked after KDoubleSpinBox !
+ else if((*it)->inherits(TQSPINBOX_OBJECT_NAME_STRING))
{
- QSpinBox *c = dynamic_cast<QSpinBox *>(*it);
+ TQSpinBox *c = dynamic_cast<TQSpinBox *>(*it);
if(c && t != settings.end())
{
@@ -134,9 +134,9 @@ void SQ_CodecSettingsSkeleton::recursivelyReadWrite(fmt_settings &settings, bool
if(c && t != settings.end())
{
if(r)
- c->setColor(QColor((*t).second.sVal));
+ c->setColor(TQColor(TQString((*t).second.sVal)));
else
- (*t).second.sVal = c->color().name().ascii();
+ (*t).second.sVal = TQString(c->color().name()).ascii();
}
}
}
@@ -149,16 +149,16 @@ int SQ_CodecSettingsSkeleton::exec(fmt_settings &settings)
sett = &settings;
- int result = QDialog::exec();
+ int result = TQDialog::exec();
// save settings
- if(result == QDialog::Accepted)
+ if(result == TQDialog::Accepted)
recursivelyReadWrite(settings, false);
return result;
}
-void SQ_CodecSettingsSkeleton::setCodecInfo( const QPixmap &pixmap, const QString &text )
+void SQ_CodecSettingsSkeleton::setCodecInfo( const TQPixmap &pixmap, const TQString &text )
{
codecIcon->setPixmap(pixmap);
codecName->setText(text);
@@ -2,7 +2,7 @@
**
** If you wish to add, delete or rename functions or slots use
-** Qt Designer which will update this file, preserving your code. Create an
+** TQt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.